@@ -718,6 +718,8 @@ class Database:
                     if 'participants_participant_' in col:
                         df = df.rename(columns={col:col.replace('participants_participant_','participants_')})
 
+                df['total_non_ccass_participants_shares'] = df['total_issued_shares'] - df['total_ccass_participants_shares']
+
                 return df
 
         else:
@@ -986,7 +988,7 @@ class Database:
                 if index_name == 'hsi_const_hist':
                     mode = df['end_date'].mode()[0]
                     df['is_alive'] = df['is_alive'].astype(bool)
-                    df['is_delisted'] = df['is_delisted'].astype(bool)
+                    #df['is_delisted'] = df['is_delisted'].astype(bool)
                     df = df.rename(columns={'is_alive':'is_active'})
 
                     for i in range(len(df)):
@@ -996,6 +998,7 @@ class Database:
                     for col in df.columns:
                         if col == 'start_date' or col == 'end_date':
                             df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
+                    df = df[['code','name','start_date','end_date','is_active']]
 
                 if index_name == 'hk_opt_stocks':
                     df = df.rename(columns={'ATS_code':'code'})
@@ -1102,6 +1105,7 @@ class Database:
 
             df['market_capital'] = df['market_capital'].map(lambda x:round(x,0))
             df['market_capital'] = df['market_capital'].astype('int64')
+            df['is_stop_trading'] = df['is_stop_trading'].map({'True': True, 'False': False})
 
             df = df[['code','stock_name','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date', 'is_stop_trading']]
 
